@@ -144,6 +144,8 @@
 /* #undef HAVE_COPYSIGNF */
 #define HAVE_COS 1
 #define HAVE_COSF 1
+/* #undef HAVE_EXP */
+/* #undef HAVE_EXPF */
 #define HAVE_FABS 1
 /* #undef HAVE_FABSF */
 #define HAVE_FLOOR 1
@@ -197,7 +199,7 @@
 #define HAVE_FCITX_FRONTEND_H 1
 #define HAVE_IBUS_IBUS_H 1
 /* #undef HAVE_IMMINTRIN_H */
-/* #undef HAVE_LIBSAMPLERATE_H */
+#define HAVE_LIBSAMPLERATE_H 1
 #define HAVE_LIBUDEV_H 1
 
 /* #undef HAVE_D3D_H */
@@ -207,6 +209,11 @@
 /* #undef HAVE_DINPUT_H */
 #define HAVE_XINPUT_H 1
 /* #undef HAVE_DXGI_H */
+
+/* #undef HAVE_ENDPOINTVOLUME_H */
+/* #undef HAVE_MMDEVICEAPI_H */
+/* #undef HAVE_AUDIOCLIENT_H */
+
 /* #undef HAVE_XINPUT_GAMEPAD_EX */
 /* #undef HAVE_XINPUT_STATE_EX */
 
@@ -221,6 +228,7 @@
 /* #undef SDL_FILE_DISABLED */
 /* #undef SDL_JOYSTICK_DISABLED */
 /* #undef SDL_HAPTIC_DISABLED */
+/* #undef SDL_SENSOR_DISABLED */
 /* #undef SDL_LOADSO_DISABLED */
 /* #undef SDL_RENDER_DISABLED */
 /* #undef SDL_THREADS_DISABLED */
@@ -245,8 +253,8 @@
 /* #undef SDL_AUDIO_DRIVER_FUSIONSOUND */
 /* #undef SDL_AUDIO_DRIVER_FUSIONSOUND_DYNAMIC */
 /* #undef SDL_AUDIO_DRIVER_HAIKU */
-/* #undef SDL_AUDIO_DRIVER_JACK */
-/* #undef SDL_AUDIO_DRIVER_JACK_DYNAMIC */
+#define SDL_AUDIO_DRIVER_JACK 1
+#define SDL_AUDIO_DRIVER_JACK_DYNAMIC "libjack.so.0"
 /* #undef SDL_AUDIO_DRIVER_NAS */
 /* #undef SDL_AUDIO_DRIVER_NAS_DYNAMIC */
 /* #undef SDL_AUDIO_DRIVER_NETBSD */
@@ -285,6 +293,10 @@
 /* #undef SDL_HAPTIC_XINPUT */
 /* #undef SDL_HAPTIC_ANDROID */
 
+/* Enable various sensor drivers */
+/* #undef SDL_SENSOR_ANDROID */
+#define SDL_SENSOR_DUMMY 1
+
 /* Enable various shared object loading systems */
 #define SDL_LOADSO_DLOPEN 1
 /* #undef SDL_LOADSO_DUMMY */
@@ -399,7 +411,7 @@
 /* #undef SDL_ALTIVEC_BLITTERS */
 
 /* Enable dynamic libsamplerate support */
-/* #undef SDL_LIBSAMPLERATE_DYNAMIC */
+#define SDL_LIBSAMPLERATE_DYNAMIC "libsamplerate.so.0"
 
 /* Platform specific definitions */
 #if !defined(__WIN32__)
